AdvancedDioLogger class
Advanced Dio HTTP client logger with rich features.
Attach this interceptor to a Dio instance to automatically log
requests, responses, and errors to Talker.
Features:
- cURL command generation (with option to hide sensitive data)
- Interactive JSON viewer with search
- Image preview support
- HTML preview support
- Large data truncation and download
- Response time tracking
Constructors
- AdvancedDioLogger({Talker? talker, AdvancedDioLoggerSettings? settings})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings ↔ AdvancedDioLoggerSettings
-
Logger settings.
getter/setter pair
- talker → Talker
-
The
Talkerinstance used for logging.no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
DioException err, ErrorInterceptorHandler handler) → void - Called when an exception was occurred during the request.
-
onRequest(
RequestOptions options, RequestInterceptorHandler handler) → void - Called when the request is about to be sent.
-
onResponse(
Response response, ResponseInterceptorHandler handler) → void - Called when the response is about to be resolved.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateSettings(
AdvancedDioLoggerSettings newSettings) → void - Replace the current settings at runtime.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited